<?php

namespace App\Repository;

use App\Entity\Referral;
use App\Entity\User;
use App\Entity\VisitNote;
use DateTimeImmutable;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Persistence\ManagerRegistry;

/**
 * @extends ServiceEntityRepository<VisitNote>
 */
class VisitNoteRepository extends ServiceEntityRepository
{
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, VisitNote::class);
    }

    public function getOrderedNotes(Referral $referral): array
    {
        return $this->createQueryBuilder('v')
            ->andWhere('v.referral = :referral')
            ->setParameter('referral', $referral->getId()->toBinary())
            ->orderBy('v.date', 'DESC')
            ->addOrderBy('v.startTime', 'DESC')
            ->getQuery()
            ->getResult()
        ;
    }

    public function filterNotes(User $user, ?Referral $referral = null, ?DateTimeImmutable $startDate = null, ?DateTimeImmutable $endDate = null): array
    {
        $query = $this->createQueryBuilder('v')
            ->join('v.referral', 'r')
        ;

        if ($referral) {
            $query->andWhere('v.referral = :referral')
                ->setParameter('referral', $referral->getId()->toBinary());
        }

        if ($startDate) {
            $query->andWhere('v.date >= :startDate')
                ->setParameter('startDate', $startDate);
        }

        if ($endDate) {
            $query->andWhere('v.date <= :endDate')
                ->setParameter('endDate', $endDate);
        }

        return $query->orderBy('v.date', 'DESC')
            ->addOrderBy('v.startTime', 'DESC')
            ->getQuery()
            ->getResult()
        ;
    }

    //    /**
    //     * @return VisitNote[] Returns an array of VisitNote objects
    //     */
    //    public function findByExampleField($value): array
    //    {
    //        return $this->createQueryBuilder('v')
    //            ->andWhere('v.exampleField = :val')
    //            ->setParameter('val', $value)
    //            ->orderBy('v.id', 'ASC')
    //            ->setMaxResults(10)
    //            ->getQuery()
    //            ->getResult()
    //        ;
    //    }

    //    public function findOneBySomeField($value): ?VisitNote
    //    {
    //        return $this->createQueryBuilder('v')
    //            ->andWhere('v.exampleField = :val')
    //            ->setParameter('val', $value)
    //            ->getQuery()
    //            ->getOneOrNullResult()
    //        ;
    //    }
}
